# StreamSelfLink


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**href** | **str** |  | [optional] 

## Example

```python
from thousandeyes_sdk.streaming.models.stream_self_link import StreamSelfLink

# TODO update the JSON string below
json = "{}"
# create an instance of StreamSelfLink from a JSON string
stream_self_link_instance = StreamSelfLink.from_json(json)
# print the JSON string representation of the object
print(StreamSelfLink.to_json())

# convert the object into a dict
stream_self_link_dict = stream_self_link_instance.to_dict()
# create an instance of StreamSelfLink from a dict
stream_self_link_from_dict = StreamSelfLink.from_dict(stream_self_link_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


